{ config, pkgs, ... }:
{
services.nextcloud = {
    enable = true;
    configureRedis = true;
    package = pkgs.nextcloud31;
    hostName = "nextcloud.knossos";
    datadir = "/var/lib/nextcloud/";
    settings = {
      overwriteprotocol = "https";
      trusted_proxies = [ "localhost" "127.0.0.1" "100.82.24.89" ];
      trusted_domains = [ "nextcloud.knossos.arkadi.one" ];
    };
    config = {
      dbtype = "pgsql";
      dbuser = "nextcloud";
      dbhost = "/run/postgresql"; # nextcloud will add /.s.PGSQL.5432 by itself
      dbname = "nextcloud";
      adminpassFile = "/var/lib/secrets/nextcloud-admin-pass";
      adminuser = "admin";
    };
};

services.postgresql = {
    enable = true;
    ensureDatabases = [ "nextcloud" ];
    ensureUsers = [
    { name = "nextcloud";
    ensureDBOwnership = true;
    }
    ];
};

# ensure that postgres is running *before* running the setup
systemd.services."nextcloud-setup" = {
    requires = ["postgresql.service"];
    after = ["postgresql.service"];
};

services.nginx.virtualHosts."nextcloud.knossos".listen = [ { addr = "127.0.0.1"; port = 8009; } ];

}
